# abstruct
このページの目的は順番に実行することでRoborecipeの記述の理念や機能を体得することです。
以下のページを順番に実行していってください。

# index

* [01 directory](01_directory.md)
* [02 describe xml](02_describe_xml.md)
* [03 install & component](03_install_and_execute.md)
